@@ -19,11 +19,11 @@ def test_sample_units():
 @pytest.mark.parametrize(
     ('obsmode', 'ans'),
     [('acs,hrc,f555w', 357.17),
-     ('acs,sbc,f122m', 90.181221),
+     ('acs,sbc,f122m', 86.209624),
      ('acs,wfc1,f775w,pol_v', 444.05),
      ('cos,boa,nuv,mirrora', 370.65),
      ('nicmos,1,f090m,dn', 559.59),
-     ('stis,0.2x29,mirror,fuvmama', 135.35817327741896),
+     ('stis,0.2x29,mirror,fuvmama', 134.977476),
      ('wfc3,ir,f164n', 700.05),
      ('wfc3,uvis1,f336w', 158.44),
      ('wfc3,uvis2,f336w', 158.36)])
@@ -35,10 +35,10 @@ def test_photbw(obsmode, ans):
     .. note::
 
         For stis,0.2x29,mirror,fuvmama, Synphot value was 134.79.
-        New ref value from STIS data update for PySynphot in Apr 2017.
+        New ref value from STIS data update some time after April 2017.
 
         For acs,sbc,f122m, new ref value from ACS data update in
-        ACS-14 (JIRA issue).
+        Oct 2019 (Avila et al.).
 
     """
     band = ObsBandpass(obsmode)
